ReceiptDurability

Enum ReceiptDurability 

pub enum ReceiptDurability {
    Buffered,
    Flushed,
    Synced,
}
The durability actually achieved for an append, as reported on the AppendReceipt. The receipt states this rather than leaving the caller to infer it from the method used.

Variants



Buffered

Accepted into memory only.



Flushed

Handed to the operating system.



Synced

Synchronized to durable storage.